Module schema

Module schema 

Schema utilities for Qdrant DataFusion integration.

Functions

collection_to_arrow_schema
Convert a collection’s configuration info into an Arrow schema.
create_vector_field
Simple helper function to create a vector field
create_vector_param_field
Simple helper function to create a list field for vector parameters
datatype_to_arrow
Simple helper function to convert a Qdrant datatype to an Arrow datatype.
is_multi_vector_field
Simple helper function to determine if a field is a multi-vector