Schema utilities for Qdrant DataFusion integration.
Functions
- collection_
to_ arrow_ schema - Convert a collection’s configuration info into an Arrow schema.
- create_
vector_ field - Simple helper function to create a vector field
- create_
vector_ param_ field - Simple helper function to create a list field for vector parameters
- datatype_
to_ arrow - Simple helper function to convert a Qdrant datatype to an Arrow datatype.
- is_
multi_ vector_ field - Simple helper function to determine if a field is a multi-vector